==> amaya_2.4.orig.tar.gz: Amaya/thotlib/base/actions.c <==
/*
 * Copyright (c) 1996 INRIA, All rights reserved
 */

/*
 * Warning:
 * This module is part of the Thot library, which was originally
 * developed in French. That's why some comments are still in
 * French, but their translation is in progress and the full module
 * will be available in English in the next release.
 *
 */

/*
 *
 * Handle actions of Thot library
 *
 * Authors: I. Vatton (INRIA)
 * Changed: S. Bonhomme (INRIA) 
 *          R. Guetari (W3C/INRIA) - Unicode and Windows version
 */

#include "thot_gui.h"
#include "thot_sys.h"
#include "appstruct.h"
#include "constmedia.h"
#include "appdialogue.h"
#undef THOT_EXPORT
#define THOT_EXPORT extern

#include "appdialogue_tv.h"

/*----------------------------------------------------------------------
   TteConnectAction rend accessible une action locale (Callback).
  ----------------------------------------------------------------------*/
#ifdef __STDC__
void                TteConnectAction (int id, Proc procedure)
#else  /* __STDC__ */
void                TteConnectAction (id, procedure)
int                 id;
Proc                procedure;

#endif /* __STDC__ */
{
   ThotLocalActions[id] = procedure;
}
 
/*----------------------------------------------------------------------
   TtaSetBackup connects the backup function: procedure().
  ----------------------------------------------------------------------*/
#ifdef __STDC__
void                TtaSetBackup (Proc procedure)
#else  /* __STDC__ */
void                TtaSetBackup (procedure)
Proc                procedure;
#endif /* __STDC__ */
{
  TteConnectAction (T_backuponfatal, procedure);
}
 
/*----------------------------------------------------------------------
   TtaSetDocStatusUpdate connects the function: procedure().
   That procedure will receive two paramters:
   - doc which is the concerned document
   - modified which gives the new status (TRUE if it's modified) of the document.
  ----------------------------------------------------------------------*/
#ifdef __STDC__
void                TtaSetDocStatusUpdate (Proc procedure)
#else  /* __STDC__ */
void                TtaSetDocStatusUpdate (procedure)
Proc                procedure;
#endif /* __STDC__ */
{
  TteConnectAction (T_docmodified, procedure);
}

==> amaya_8.5.orig.tar.gz: Amaya/thotlib/base/actions.c <==
/*
 *  (c) COPYRIGHT INRIA, 1996-2004
 *  Please first read the full copyright statement in file COPYRIGHT.
 */

/*
 *
 * Handle actions of Thot library
 *
 * Authors: I. Vatton (INRIA)
 * Changed: S. Bonhomme (INRIA) 
 */
#include "thot_gui.h"
#include "thot_sys.h"
#include "appstruct.h"
#include "constmedia.h"
#include "appdialogue.h"


#undef THOT_EXPORT
#define THOT_EXPORT extern

#include "appdialogue_tv.h"

/*----------------------------------------------------------------------
   TteConnectAction rend accessible une action locale (Callback).
  ----------------------------------------------------------------------*/
void TteConnectAction (int id, Proc procedure)
{
   ThotLocalActions[id] = procedure;
}
 
/*----------------------------------------------------------------------
   TtaSetBackup connects the backup function: procedure().
  ----------------------------------------------------------------------*/
void TtaSetBackup (Proc procedure)
{
  TteConnectAction (T_backuponfatal, procedure);
}
 
/*----------------------------------------------------------------------
   TtaSetAutoSave connects the AutoSave function: procedure().
  ----------------------------------------------------------------------*/
void TtaSetAutoSave (Proc procedure)
{
  TteConnectAction (T_autosave, procedure);
}
 
/*----------------------------------------------------------------------
   TtaSetDocStatusUpdate connects the function: procedure().
   That procedure will receive two paramters:
   - doc which is the concerned document
   - modified which gives the new status (TRUE if it's modified) of the document.
  ----------------------------------------------------------------------*/
void TtaSetDocStatusUpdate (Proc procedure)
{
  TteConnectAction (T_docmodified, procedure);
}
